@@ -82,6 +82,10 @@ class ConnectionParser:
         Returns:
             Connection string with password special characters encoded
         """
+        # Handle None connection string
+        if connection_string is None:
+            return ""
+
         if "://" not in connection_string:
             return connection_string
 
@@ -306,15 +310,25 @@ class ConnectionParser:
             connection_string: Database connection string
 
         Returns:
-            Database type: 'postgresql', 'mysql', or 'sqlite'
+            Database type: 'postgresql', 'mysql', 'sqlite', or 'mongodb'
 
         Raises:
             AdapterError: If database type cannot be determined
         """
         try:
+            # Handle None connection string
+            if connection_string is None:
+                raise AdapterError("Connection string is None")
+
             # Enhanced SQLite pattern detection
             connection_lower = connection_string.lower()
 
+            # MongoDB detection (before SQLite patterns)
+            if connection_lower.startswith("mongodb://") or connection_lower.startswith(
+                "mongodb+srv://"
+            ):
+                return "mongodb"
+
             # Common SQLite indicators
             if (
                 connection_string == ":memory:"
@@ -340,13 +354,18 @@ class ConnectionParser:
                     return "mysql"
                 elif scheme in ["sqlite"]:
                     return "sqlite"
+                elif scheme in ["mongodb"]:
+                    return "mongodb"
                 elif not scheme:
                     # No scheme found - likely a file path (SQLite)
                     return "sqlite"
                 else:
                     raise AdapterError(f"Unsupported database scheme: {scheme}")
             except Exception:
-                # If URL parsing fails, assume it's a file path (SQLite)
+                # If URL parsing fails, check if it's a MongoDB URI
+                if "mongodb" in connection_lower:
+                    return "mongodb"
+                # Otherwise assume it's a file path (SQLite)
                 return "sqlite"
 
         except Exception as e:
