@@ -7,9 +7,10 @@ Provides document database operations using Motor async driver.
 import logging
 from typing import Any, Dict, List, Optional, Tuple
 
-from dataflow.adapters.base_adapter import BaseAdapter
 from motor.motor_asyncio import AsyncIOMotorClient, AsyncIOMotorDatabase
 
+from dataflow.adapters.base_adapter import BaseAdapter
+
 logger = logging.getLogger(__name__)
 
 
@@ -161,7 +162,7 @@ class MongoDBAdapter(BaseAdapter):
         Raises:
             Exception: If health check fails
         """
-        if not self._connected or not self._client:
+        if not self._connected or self._client is None:
             return {"connected": False, "database": None, "error": "Not connected"}
 
         try:
@@ -244,7 +245,7 @@ class MongoDBAdapter(BaseAdapter):
             ValueError: If document is empty
             Exception: If insert fails
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not document:
@@ -282,7 +283,7 @@ class MongoDBAdapter(BaseAdapter):
             ValueError: If documents list is empty
             Exception: If insert fails
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not documents:
@@ -320,7 +321,7 @@ class MongoDBAdapter(BaseAdapter):
             >>> doc = await adapter.find_one("users", {"email": "alice@example.com"})
             >>> doc = await adapter.find_one("users", {"age": {"$gte": 18}})
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -370,7 +371,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     sort=[("name", 1), ("created_at", -1)]
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         filter = filter or {}
@@ -428,7 +429,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     {"$set": {"status": "active"}}
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not filter:
@@ -481,7 +482,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     {"$set": {"archived": True}}
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not filter:
@@ -521,7 +522,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     {"email": "alice@example.com"}
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not filter:
@@ -558,7 +559,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     {"status": "inactive"}
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not filter:
@@ -594,7 +595,7 @@ class MongoDBAdapter(BaseAdapter):
         Example:
             >>> count = await adapter.count_documents("users", {"status": "active"})
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         filter = filter or {}
@@ -633,7 +634,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     {"$limit": 10}
             ... ])
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not pipeline:
@@ -688,7 +689,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     [("last_name", 1), ("first_name", 1)]
             ... )
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         if not keys:
@@ -722,7 +723,7 @@ class MongoDBAdapter(BaseAdapter):
             >>> for index in indexes:
             ...     print(f"{index['name']}: {index['key']}")
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -748,7 +749,7 @@ class MongoDBAdapter(BaseAdapter):
         Example:
             >>> await adapter.drop_index("users", "email_1")
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -785,7 +786,7 @@ class MongoDBAdapter(BaseAdapter):
             ...     }
             ... })
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -806,7 +807,7 @@ class MongoDBAdapter(BaseAdapter):
         Example:
             >>> await adapter.drop_collection("temp_data")
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -828,7 +829,7 @@ class MongoDBAdapter(BaseAdapter):
             >>> collections = await adapter.list_collections()
             >>> print(f"Found {len(collections)} collections")
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
@@ -855,7 +856,7 @@ class MongoDBAdapter(BaseAdapter):
             >>> if await adapter.collection_exists("users"):
             ...     print("Users collection exists")
         """
-        if not self._connected or not self._db:
+        if not self._connected or self._db is None:
             raise ConnectionError("Not connected to MongoDB")
 
         try:
