@@ -4,6 +4,7 @@ DataFlow Bulk Operations
 High-performance bulk database operations.
 """
 
+import json
 from typing import Any, Dict, List
 
 
@@ -13,6 +14,29 @@ class BulkOperations:
     def __init__(self, dataflow_instance):
         self.dataflow = dataflow_instance
 
+    @staticmethod
+    def _serialize_params_for_sql(params: list) -> list:
+        """Serialize dict/list parameters to JSON for SQL binding.
+
+        BUG #515 FIX: This method ensures dict/list values are serialized
+        to JSON strings at the SQL parameter binding stage, NOT during
+        validation. This preserves type integrity through validation while
+        ensuring database compatibility.
+
+        Args:
+            params: List of parameter values
+
+        Returns:
+            List with dict/list values serialized to JSON strings
+        """
+        serialized = []
+        for value in params:
+            if isinstance(value, (dict, list)):
+                serialized.append(json.dumps(value))
+            else:
+                serialized.append(value)
+        return serialized
+
     def _build_where_clause(
         self,
         filter_criteria: Dict[str, Any],
@@ -288,7 +312,10 @@ class BulkOperations:
                         placeholders = ", ".join(["?"] * len(columns))
 
                     values_placeholders.append(f"({placeholders})")
-                    params.extend([record.get(col) for col in columns])
+                    record_params = [record.get(col) for col in columns]
+                    # BUG #515 FIX: Serialize dict/list for SQL parameter binding
+                    record_params = self._serialize_params_for_sql(record_params)
+                    params.extend(record_params)
 
                 values_clause = ", ".join(values_placeholders)
                 query = (
@@ -431,7 +458,11 @@ class BulkOperations:
                         set_parts.append(f"{field} = %s")
                     else:  # sqlite
                         set_parts.append(f"{field} = ?")
-                    params.append(value)
+                    # BUG #515 FIX: Serialize dict/list for SQL parameter binding
+                    if isinstance(value, (dict, list)):
+                        params.append(json.dumps(value))
+                    else:
+                        params.append(value)
 
                 set_clause = "SET " + ", ".join(set_parts)
 
@@ -549,7 +580,11 @@ class BulkOperations:
                                 set_parts.append(f"{field} = %s")
                             else:  # sqlite
                                 set_parts.append(f"{field} = ?")
-                            params.append(value)
+                            # BUG #515 FIX: Serialize dict/list for SQL parameter binding
+                            if isinstance(value, (dict, list)):
+                                params.append(json.dumps(value))
+                            else:
+                                params.append(value)
 
                         if not set_parts:
                             logger.warning(
