@@ -158,7 +158,8 @@ class BulkUpdateNode(SmartNodeConnectionMixin, AsyncNode):
             dry_run = validated_inputs.get("dry_run", False)
 
             # Validate input combinations
-            if not filter_conditions and not ids and not data:
+            # Use key existence check instead of truthiness to allow empty filter {}
+            if "filter" not in validated_inputs and not ids and not data:
                 raise NodeValidationError(
                     "Either filter conditions, ids, or data must be provided"
                 )
